@@ -1,7 +1,5 @@
 package Class::Delegation;
-
-our $VERSION = '1.009001';
-
+$VERSION = '1.05';
 use strict;
 use Carp;
 
@@ -10,278 +8,221 @@ sub ::DEBUG { 0 };
 my %mappings;
 
 sub import {
-    my $class = shift;
-    my $caller = caller();
-    while (@_) {
-        push @{$mappings{$caller}}, Class::Delegation::->_new(\@_);
-    }
+	my $class = shift;
+	my $caller = caller();
+	while (@_) {
+		push @{$mappings{$caller}}, Class::Delegation::->new(\@_);
+	}
 }
 
 INIT {
-    foreach my $class (keys %mappings) {
-        _install_delegation_for($class);
-    }
+	foreach my $class (keys %mappings) {
+		install_delegation_for($class);
+	}
 }
 
-sub _install_delegation_for {
-    use vars '$AUTOLOAD';
-    no strict 'refs';
-    my ($class) = @_;
-    my $symbol = "${class}::AUTOLOAD";
-    print STDERR "Installing $symbol\n" if ::DEBUG;
-    my $real_AUTOLOAD = *{$symbol}{CODE}
-             || sub {croak "Could not delegate $AUTOLOAD"};
-        
-    local $SIG{__WARN__} = sub {};
-    *$symbol = sub {
-        $$symbol = $AUTOLOAD;
-        my ($class, $method) = $AUTOLOAD =~ m/(.*::)(.*)/;
-        my ($invocant, @args) = @_;
-        print STDERR "Delegating: $AUTOLOAD...\n" if ::DEBUG;
-        use Data::Dumper 'Dumper';
-        print STDERR "...on: ", Dumper $invocant if ::DEBUG;
-        my @context = ($invocant, $method, @args);
-        $invocant = "${class}${invocant}" unless ref $invocant;
-        my $wantarray = wantarray;
-        my @delegators = _delegators_for(@context);
-        goto &{$real_AUTOLOAD} unless @delegators;
-        my (@results, $delegated);
-        DELEGATOR: foreach my $delegator ( @delegators ) {
-            next if $delegator->{other} && keys %$delegated;
-            my @to = @{$delegator->{to}};
-            my @as = @{$delegator->{as}}; 
-            if (@to==1) {
-                print STDERR "[$to[0]]\n" if ::DEBUG;
-                next DELEGATOR if exists $delegated->{$to[0]};
-                foreach my $as (@as) {
-                    push @results, delegate($delegated,$wantarray,$invocant,$to[0],$as,\@args);
-                }
-            }
-            elsif (@as==1) {
-                print STDERR "[$to[0]]\n" if ::DEBUG;
-                foreach my $to (@to) {
-                    next if exists $delegated->{$to};
-                    push @results, delegate($delegated,$wantarray,$invocant,$to,$as[0],\@args);
-                }
-            }
-            else {
-                while (1) {
-                    last unless @to && @as;
-                    my $to = shift @to;
-                    my $as = shift @as;
-                    next if exists $delegated->{$to};
-                    push @results, delegate($delegated,$wantarray,$invocant,$to,$as,\@args);
-                }
-            }
-        }
-        goto &{$real_AUTOLOAD} unless keys %$delegated;
-        return $wantarray
-            ? ( @results>1 ? @results : @{$results[0]} )
-            : ( @results>1 ? \@results : $results[0] );
-    };
+sub install_delegation_for {
+	use vars '$AUTOLOAD';
+	no strict 'refs';
+	my ($class) = @_;
+	my $symbol = "${class}::AUTOLOAD";
+	print "Installing $symbol\n" if ::DEBUG;
+	my $real_AUTOLOAD = *{$symbol}{CODE}
+			 || sub {croak "Could not delegate $AUTOLOAD"};
+		
+	local $SIG{__WARN__} = sub {};
+	*$symbol = sub {
+		$$symbol = $AUTOLOAD;
+		my ($class, $method) = $AUTOLOAD =~ m/(.*::)(.*)/;
+		my ($invocant, @args) = @_;
+		print STDERR "Delegating: $AUTOLOAD...\n" if ::DEBUG;
+		use Data::Dumper 'Dumper';
+		print "...on: ", Dumper $invocant if ::DEBUG;
+		my @context = ($invocant, $method, @args);
+		$invocant = "${class}${invocant}" unless ref $invocant;
+		my $wantarray = wantarray;
+		my @delegators = delegators_for(@context);
+		goto &{$real_AUTOLOAD} unless @delegators;
+		my (@results, $delegated);
+		foreach my $delegator ( @delegators ) {
+			next if $delegator->{other} && keys %$delegated;
+			foreach my $to (@{$delegator->{to}}) {
+				my $as = $delegator->{as};
+				print STDERR "[$to]\n" if ::DEBUG;
+				next if exists $delegated->{$to};
+				push @results, delegate($delegated,$wantarray,$invocant,$to,$as,\@args);
+			}
+		}
+		goto &{$real_AUTOLOAD} unless keys %$delegated;
+		return $wantarray
+			? ( @results>1 ? @results : @{$results[0]} )
+			: ( @results>1 ? \@results : $results[0] );
+	};
 
-    unless ($class->can('DESTROY') || _delegators_for($class,'DESTROY')) {
-        *{"${class}::DESTROY"} = sub {};
-    }
+	unless (*{"${class}::DESTROY"}{CODE} ||
+		delegators_for($class,'DESTROY')) {
+		*{"${class}::DESTROY"} = sub {};
+	}
 }
 
 sub delegate {
-    my ($delegated,$wantarray,$invocant,$to,$as,$args) = @_;
-    no strict 'refs';
-    my $target = ref $to            ? $to
-           : $to =~ /^->(\w+)$/ ? $invocant->$+()
-           : $to eq -SELF       ? $invocant
-           :                      $invocant->{$to};
-    return unless eval {
-        $target->can($as)  || $target->can('AUTOLOAD')
-    };
-    my $result = $wantarray
-            ? [$target->$as(@$args)]
-            : $target->$as(@$args);
-    return if $@;
-    $_[0]->{$to}++;
-    return $result
+	my ($delegated,$wantarray,$invocant,$to,$as,$args) = @_;
+	no strict 'refs';
+	return unless eval { $invocant->{$to}->can($as) };
+	my $result = $wantarray
+			? eval { [$invocant->{$to}->$as(@$args)] }
+			: eval {  $invocant->{$to}->$as(@$args)  };
+	return if $@;
+	$_[0]->{$to}++;
+	return $result
 }
 
-sub _delegators_for {
-    my ($self, $method, @args) = @_;
+sub delegators_for {
+	my ($self, $method, @args) = @_;
 
-    my @attrs;
-    my $class = ref($self)||$self;
-    foreach my $candidate ( @{$mappings{$class}} ) {
-        push @attrs, $candidate->{send}->can_send(scalar(@attrs),
-                              $candidate->{to},
-                              $candidate->{as},
-                              @_);
-    }
-    return @attrs if @attrs;
-        no strict 'refs';
-    my @ancestors = @{$class.'::ISA'};
-    my $parent;
-    while ($parent = shift @ancestors) {
-        next unless exists $mappings{$parent};
-        foreach my $candidate ( @{$mappings{$parent}} ) {
-        push @attrs, $candidate->{send}->can_send(scalar(@attrs),
-                              $candidate->{to},
-                              $candidate->{as},
-                              @_);
-        }
-        return @attrs if @attrs;
-        unshift @ancestors, @{$parent.'::ISA'};
-    }
-    return @attrs;
+	my @attrs;
+	foreach my $candidate ( @{$mappings{ref($self)||$self}} ) {
+		push @attrs, $candidate->{send}->can_send(scalar(@attrs),
+							  $candidate->{to},
+							  $candidate->{as},
+							  @_);
+	}
+	return @attrs;
 }
 
-sub _new {
-    my ($class, $args) = @_;
-    my ($send, $send_val) = splice @$args, 0, 2;
-    croak "Expected 'send => <method spec>' but found '$send => $send_val'"
-        unless $send eq 'send';
-    croak "The expected 'to => <attribute spec>' is missing at end of list"
-        unless @$args >= 2;
-    my ($to, $to_val) = splice @$args, 0, 2;
-    croak "Expected 'to => <attribute spec>' but found '$to => $to_val'"
-        unless $to eq 'to';
+sub new {
+	my ($class, $args) = @_;
+	my ($send, $send_val) = splice @$args, 0, 2;
+	croak "Expected 'send => <method spec>' but found '$send => $send_val'"
+		unless $send eq 'send';
+	croak "The expected 'to => <attribute spec>' is missing at end of list"
+		unless @$args >= 2;
+	my ($to, $to_val) = splice @$args, 0, 2;
+	croak "Expected 'to => <attribute spec>' but found '$to => $to_val'"
+		unless $to eq 'to';
 
-    $send_val  = _class_for(Send => $send_val)->_new($send_val);
-    my $to_obj = _class_for(To => $to_val)->_new($to_val);
-    my $self = bless { send=>$send_val, to=>$to_obj }, $class;
-    if (($args->[0]||"") eq 'as') {
-        my ($as, $as_val) = splice @$args, 0, 2;
-        croak "Arrays specified for 'to' and 'as' must be same length"
-            unless ref($to_val) ne 'ARRAY'
-                || ref($as_val) ne 'ARRAY'
-                || @$to_val == @$as_val;
-        $self->{as} = _class_for(As => $as_val)->_new($as_val);
-    }
-    else {
-        croak "'to => -SELF' is meaningless without 'as => <new_name>'"
-            if $to_val eq -SELF;
-        $self->{as} = Class::Delegation::As::Sent->_new();
-    }
-    return $self;
+	$send_val = class_for(Send => $send_val)->new($send_val);
+	$to_val   = class_for(To => $to_val)->new($to_val);
+	my $self = bless { send=>$send_val, to=>$to_val }, $class;
+	if (($args->[0]||"") eq 'as') {
+		my ($as, $as_val) = splice @$args, 0, 2;
+		$self->{as} = class_for(As => $as_val)->new($as_val);
+	}
+	else {
+		$self->{as} = Class::Delegation::As::Sent->new();
+	}
+	return $self;
 }
 
 my %allowed;
 @{$allowed{Send}}{qw(ARRAY Regexp CODE)} = ();
 @{$allowed{To}}{qw(ARRAY Regexp CODE)} = ();
-@{$allowed{As}}{qw(ARRAY CODE)} = ();
+@{$allowed{As}}{qw(CODE)} = ();
 
-sub _class_for {
-    my ($subclass, $value) = @_;
-    my $type = ref($value);
-    return "Class::Delegation::${subclass}::SCALAR" unless $type;
-    croak "'\l$subclass' value cannot be $type reference"
-        unless exists $allowed{$subclass}{$type};
-    return "Class::Delegation::${subclass}::${type}";
+sub class_for {
+	my ($subclass, $value) = @_;
+	my $type = ref($value);
+	return "Class::Delegation::${subclass}::SCALAR" unless $type;
+	croak "'\l$subclass' value cannot be $type reference"
+		unless exists $allowed{$subclass}{$type};
+	return "Class::Delegation::${subclass}::${type}";
 }
 
-package # Hide from CPAN indexer
-SELF;
-
-sub DESTROY {}
-sub AUTOLOAD {
-    my ($name) = $SELF::AUTOLOAD =~ m/.*::(.+)/;
-    bless \$name, 'SELF'
-}
-use overload 'neg' => sub { "->${$_[0]}" };
-
-
 package Class::Delegation::Send::SCALAR;
 
-sub _new {
-    return bless {}, "Class::Delegation::Send::ALL" if $_[1] eq '-ALL';
-    return bless {}, "Class::Delegation::Send::OTHER" if $_[-1] eq '-OTHER';
-    my $val = pop;
-    return bless \$val, $_[0]
+sub new {
+	return bless {}, "Class::Delegation::Send::ALL" if $_[1] eq '-ALL';
+	return bless {}, "Class::Delegation::Send::OTHER" if $_[-1] eq '-OTHER';
+	my $val = pop;
+	return bless \$val, $_[0]
 }
 
 sub can_send {
-    my ($self, $sent, $to, $as, @context) = @_;
-    return { to => [$to->attr_for(@context)],
-         as => [$as->name_for(@context)],
-           }
-        if $$self eq $context[1];
-    return;
+	my ($self, $sent, $to, $as, @context) = @_;
+	return { to => [$to->attr_for(@context)],
+		 as => $as->name_for(@context),
+	       }
+		if $$self eq $context[1];
+	return;
 }
 
 
 package Class::Delegation::Send::ARRAY;
 
-sub _new {
-    my @delegators =
-        map { Class::Delegation::_class_for(Send => $_)->_new($_) } @{$_[1]};
-    bless \@delegators, $_[0];
+sub new {
+	my @delegators =
+	    map { Class::Delegation::class_for(Send => $_)->new($_) } @{$_[1]};
+	bless \@delegators, $_[0];
 }
 
 sub can_send {
-    my ($self, @context) = @_;
-    return map { $_->can_send(@context) } @$self;
+	my ($self, @context) = @_;
+	return map { $_->can_send(@context) } @$self;
 }
 
 
 package Class::Delegation::Send::Regexp;
 
-sub _new {
-    my ($class, $regex) = @_;
-    my $self = bless \$regex, $class;
-    return $self;
+sub new {
+	my ($class, $regex) = @_;
+	my $self = bless \$regex, $class;
+	return $self;
 }
 
 
 sub can_send {
-    my ($self, $sent, $to, $as, @context) = @_;
-    return { to => [$to->attr_for(@context)],
-         as => [$as->name_for(@context)],
-           }
-        if $context[1] =~ $$self;
-    return;
+	my ($self, $sent, $to, $as, @context) = @_;
+	return { to => [$to->attr_for(@context)],
+		 as => $as->name_for(@context),
+	       }
+		if $context[1] =~ $$self;
+	return;
 }
 
 
 package Class::Delegation::Send::CODE;
 
-sub _new { bless $_[1], $_[0] }
+sub new { bless $_[1], $_[0] }
 
 sub can_send {
-    my ($self, $sent, $to, $as, @context) = @_;
-    return { to => [$to->attr_for(@context)],
-         as => [$as->name_for(@context)],
-           }
-        if $self->(@context);
-    return;
+	my ($self, $sent, $to, $as, @context) = @_;
+	return { to => [$to->attr_for(@context)],
+		 as => $as->name_for(@context),
+	       }
+		if $self->(@context);
+	return;
 }
 
 package Class::Delegation::Send::ALL;
 
 sub can_send {
-    my ($self, $sent, $to, $as, @context) = @_;
-    return { to => [$to->attr_for(@context)],
-         as => [$as->name_for(@context)],
-           }
-        if $context[1] ne 'DESTROY';
-    return;
+	my ($self, $sent, $to, $as, @context) = @_;
+	return { to => [$to->attr_for(@context)],
+		 as => $as->name_for(@context),
+	       }
+		if $context[1] ne 'DESTROY';
+	return;
 }
 
 package Class::Delegation::Send::OTHER;
 
 sub can_send { 
-    my ($self, $sent, $to, $as, @context) = @_;
-    return { to => [$to->attr_for(@context)],
-         as => [$as->name_for(@context)],
-         other => 1,
-           }
-        if $context[1] ne 'DESTROY';
-    return;
+	my ($self, $sent, $to, $as, @context) = @_;
+	return { to => [$to->attr_for(@context)],
+		 as => $as->name_for(@context),
+		 other => 1,
+	       }
+		if $context[1] ne 'DESTROY';
+	return;
 }
 
    
 package Class::Delegation::To::SCALAR;
 
-sub _new {
-    my ($class, $value) = @_;
-    return bless {}, "Class::Delegation::To::ALL" if $value eq '-ALL';
-    return bless \$value, $class
+sub new {
+	my ($class, $value) = @_;
+	return bless {}, "Class::Delegation::To::ALL" if $value eq '-ALL';
+	return bless \$value, $class
 }
 
 sub attr_for { return ${$_[0]} }
@@ -289,85 +230,76 @@ sub attr_for { return ${$_[0]} }
 
 package Class::Delegation::To::ARRAY;
 
-sub _new {
-    my ($class, $array) = @_;
-    bless [ map {("Class::Delegation::To::".(ref||"SCALAR"))->_new($_)} @$array ], $class;
+sub new {
+	my ($class, $array) = @_;
+	bless [ map {("Class::Delegation::To::".(ref||"SCALAR"))->new($_)} @$array ], $class;
 }
 
 sub attr_for {
-    my ($self, @context) = @_;
-    return map { $_->attr_for(@context) } @$self;
+	my ($self, @context) = @_;
+	return map { $_->attr_for(@context) } @$self;
 }
 
 package Class::Delegation::To::Regexp;
 
-sub _new {
-    my ($class, $regex) = @_;
-    my $self = bless \$regex, $class;
-    return $self;
+sub new {
+	my ($class, $regex) = @_;
+	my $self = bless \$regex, $class;
+	return $self;
 }
 
 sub attr_for {
-    my ($self, $invocant, @context) = @_;
-    print STDERR "[[$$self]]\n" if ::DEBUG;
-    return grep {  $_ =~ $$self } keys %$invocant;
+	my ($self, $invocant, @context) = @_;
+	print "[[$$self]]\n" if ::DEBUG;
+	return grep {  $_ =~ $$self } keys %$invocant;
 }
 
 
 package Class::Delegation::To::CODE;
 
-sub _new { bless $_[1], $_[0] }
+sub new { bless $_[1], $_[0] }
 
 sub attr_for {
-    my ($self, @context) = @_;
-    return $self->(@context)
+	my ($self, @context) = @_;
+	return $self->(@context)
 }
 
 
 package Class::Delegation::To::ALL;
 
 sub attr_for {
-    my ($self, $invocant, @context) = @_;
-    return keys %$invocant;
+	my ($self, $invocant, @context) = @_;
+	return keys %$invocant;
 }
 
 
 
 package Class::Delegation::As::SCALAR;
 
-sub _new {
-    my ($class, $value) = @_;
-    bless \$value, $class;
+sub new {
+	my ($class, $value) = @_;
+	bless \$value, $class;
 }
 
 sub name_for { ${$_[0]} }
 
-package Class::Delegation::As::ARRAY;
-
-sub _new {
-    my ($class, $value) = @_;
-    bless $value, $class;
-}
-
-sub name_for { @{$_[0]} }
-
 
 package Class::Delegation::As::Sent;
 
-sub _new { bless {}, $_[0] }
+sub new { bless {}, $_[0] }
 
 sub name_for {
-    my ($self, $invocant, $method) = @_;
-    return $method;
+	my ($self, $invocant, $method) = @_;
+	return $method;
 }
 
 package Class::Delegation::As::CODE;
 
-sub _new { bless $_[1], $_[0] }
+sub new { bless $_[1], $_[0] }
 
 sub name_for {
-    my ($self, @context) = @_;
-    return $self->(@context)
+	my ($self, @context) = @_;
+	return $self->(@context)
 }
 
 1;
@@ -380,8 +312,8 @@ Class::Delegation - Object-oriented delegation
 
 =head1 VERSION
 
-This document describes version 1.009001 of Class::Delegation
-released April 23, 2002.
+This document describes version 1.05 of Class::Delegation,
+released December  1, 2001.
 
 =head1 SYNOPSIS
 
@@ -392,8 +324,7 @@ released April 23, 2002.
                   to => ["left_front_wheel", "right_front_wheel"],
 
                 send => 'drive',
-                  to => ["right_rear_wheel", "left_rear_wheel"],
-          as => ["rotate_clockwise", "rotate_anticlockwise"]
+                  to => ["left_rear_wheel", "right_rear_wheel"],
 
                 send => 'power',
                   to => 'flywheel',
@@ -402,10 +333,6 @@ released April 23, 2002.
                 send => 'brake',
                   to => qr/.*_wheel$/,
 
-        send => 'halt'
-          to => -SELF,
-          as => 'brake',
-
                 send => qr/^MP_(.+)/,
                   to => 'mp3',
                   as => sub { $1 },
@@ -431,15 +358,15 @@ inheritance has a fundamental limitation: a class can only directly inherit
 once from a given parent class. This limitation occasionally
 leads to awkward work-arounds like this:
 
-    package Left_Front_Wheel;   use base qw( Wheel );
-    package Left_Rear_Wheel;    use base qw( Wheel );
-    package Right_Front_Wheel;  use base qw( Wheel );
-    package Right_Rear_Wheel;   use base qw( Wheel );
+	package Left_Front_Wheel;   use base wq( Wheel );
+	package Left_Rear_Wheel;    use base wq( Wheel );
+	package Right_Front_Wheel;  use base wq( Wheel );
+	package Right_Rear_Wheel;   use base wq( Wheel );
 
-    package Car;                use base qw(Left_Front_Wheel
-                        Left_Rear_Wheel 
-                        Right_Front_Wheel
-                        Right_Rear_Wheel);
+	package Car;                use base qw(Left_Front_Wheel
+						Left_Rear_Wheel 
+						Right_Front_Wheel
+						Right_Rear_Wheel);
 
 Worse still, the method dispatch semantics of most languages (including Perl)
 require that only a single inherited method (in Perl, the one that is
@@ -568,10 +495,6 @@ to a collection of nominated attributes in parallel, or
 
 to any attribute that can handle the message.
 
-=item *
-
-the object itself
-
 =back
 
 These three delegation mechanisms can be specified for:
@@ -598,11 +521,10 @@ all methods, delegated or not.
 
 =head2 The syntax and semantics of delegation
 
-To cause a hash-based class to delegate method invocations to its
-attributes, the Class::Delegation module is imported into the class, and
-passed a list of method/handler mappings that specify the delegation
-required. Each mapping consists of between one and three key/value
-pairs. For example:
+To cause a hash-based class to delegate method invocations to its attributes, the 
+Class::Delegation module is imported into the class, and passed a list
+of method/handler mappings that specify the delegation required. Each mapping consists
+of between one and three key/value pairs. For example:
 
         package Car;
         
@@ -611,8 +533,7 @@ pairs. For example:
                   to => ["left_front_wheel", "right_front_wheel"],
                 
                 send => 'drive',
-                  to => ["right_rear_wheel", "left_rear_wheel"],
-          as => ["rotate_clockwise", "rotate_anticlockwise"]
+                  to => ["left_rear_wheel", "right_rear_wheel"],
                   
                 send => 'power',
                   to => 'flywheel',
@@ -700,31 +621,11 @@ C<$self-E<gt>{flywheel}-E<gt>power(...)>:
             send => 'power',
               to => 'flywheel';
 
-If the attribute is specified via a single string that starts with C<"->...">
-then that string is taken as specifying the name of a I<method> of the
-current object. That method is called and is expected to return an 
-object. The original method that was being delegated is then delegated to that
-object. For example, to delegate invocations of C<$self-E<gt>power(...)> to
-C<$self-E<gt>flywheel()-E<gt>power(...)>:
-
-        use Class::Delegation
-            send => 'power',
-              to => '->flywheel';
-
-Since this syntax is a little obscure (and not a little ugly),
-the same effect can also be obtained like so:
-
-        use Class::Delegation
-            send => 'power',
-              to => -SELF->flywheel;
-
-
-An array reference can be used in the attribute position to specify the
-a list of attributes, I<all of which> are delegated to -- in sequence
-they appear in the list. Note that each element of the array is
-processed recursively, so it may contain any of the other attribute
-specifiers described in this section (or, indeed, a nested array of
-attribute specifiers)
+An array reference can be used in the attribute position to specify the a list of
+attributes, I<all of which> are delegated to -- in sequence they appear in
+the list. Note that each element of the array is processed recursively, so
+it may contain any of the other attribute specifiers described in this section
+(or, indeed, a nested array of attribute specifiers)
 
 For example, to distribute invocations of C<$self-E<gt>drive(...)> to both
 C<$self-E<gt>{left_rear_wheel}-E<gt>drive(...)> and
@@ -759,22 +660,13 @@ example, to redispatch C<brake> calls to every attribute whose name ends in C<"_
         send => 'brake',
           to => qr/.*_wheel$/,
 
-If a subroutine reference is used as the C<'to'> attribute specifier, it is passed the
+If a subroutine reference is used as the attribute specifier, it is passed the
 invocant, the name of the method, and the argument list. It is expected to
-return either a value specifying the correct attribute name (or names). As with an
+return a value specifying the correct attribute name (or names). As with an
 array, the value returned may be any valid attribute specifier (including
 another subroutine reference) and is iteratively processed to determine the
 correct target(s) for delegation.
 
-A subroutine may also return a reference to an object, in which case the
-subroutine is delegated to that object (rather than to an attribute of
-the current object). This can be useful when the actual delegation target
-is more complex than just a direct attribute. For example:
-
-    send => 'start',
-      to => sub { $_[0]{ignition}{security}[$_[0]->next_key] },
-
-
 If the C<-ALL> flag is used as the name of the attribute, the method
 is delegated to all attributes of the object (in their C<keys> order). For 
 example, to forward debugging requests to every attribute in turn:
@@ -785,11 +677,10 @@ example, to forward debugging requests to every attribute in turn:
 
 =head2 Specifying the name of a delegated method
 
-Sometimes it is necessary to invoke an attribute's method through a
-different name than that of the original delegated method. The C<'as'>
-key facilitates this type of method name translation in any delegation.
-The value associated with an C<'as'> key specifies the name of the
-method to be invoked, and may be a string, an array, or a subroutine.
+Sometimes it is necessary to invoke an attribute's method through a different
+name than that of the original delegated method. The C<'as'> key facilitates this type
+of method name translation in any delegation. The value associated with an C<'as'> key specifies
+the name of the method to be invoked, and may be a string or a subroutine.
 
 If a string is provided, it is used as the new name of the delegated method.
 For example, to cause calls to C<$self-E<gt>power(...)>
@@ -799,32 +690,6 @@ to be delegated to C<$self-E<gt>{flywheel}-E<gt>brake(...)>:
           to => 'flywheel',
           as => 'brake',
 
-If an array is given, it specifies a list of delegated method names.
-If the C<'to'> key specifies a single attribute, each method in the list is
-invoked on that one attribute. For example:
-
-        send => 'boost',
-          to => 'flywheel',
-          as => ['override', 'engage', 'discharge'],
-
-would sequentially call:
-
-        $self->{flywheel}->override(...);
-        $self->{flywheel}->engage(...);
-        $self->{flywheel}->discharge(...);
-
-If both the C<'to'> key and the C<'as'> key specify multiple values, then
-each attribute and method name form a pair, which is invoked. For example:
-
-        send => 'escape',
-          to => ['flywheel', 'smokescreen'],
-          as => ['engage',   'release'],
-
-would sequentially call:
-
-        $self->{flywheel}->engage(...);
-        $self->{smokescreen}->release(...);
-
 If a subroutine reference is used as the C<'as'> specifier, it is passed the
 invocant, the name of the method, and the argument list, and is expected to
 return a string that will be used as the method name. For example, to 
@@ -842,26 +707,6 @@ or:
           as => sub { $1 }
 
 
-=head2 Delegation to self
-
-Class::Delegation can also be used to delegate methods back to the original
-object, using the C<-SELF> option with the C<'to'> key. For example, to
-redirect any call to C<overdrive> so to invoke the C<boost> method instead:
-
-       send => 'overdrive',
-         to => -SELF,
-         as => 'boost',
-
-Note that this only works if the object I<does not> already have an
-C<overdrive> method.
-
-As with other delegations, a single call can be redelegated-to-self as
-multiple calls.  For example:
-
-       send => 'emergency',
-         to => -SELF,
-         as => ['overdrive', 'launch_rockets'],
-
 
 =head2 Handling failure to delegate
 
@@ -1065,7 +910,7 @@ acts as a collective front-end for several others. For example:
                   
 
 The Bilateral class now forwards all I<class> method calls that are prefixed
-with C<"left_..."> to the Laevorotatory class, and all those prefixed with
+with C<"left_..."> to the Lvorotatory class, and all those prefixed with
 C<"right_..."> to the Dextrorotatory class. Any calls that cannot be dispatched
 are caught and ignored (with a warning) by the C<AUTOLOAD>.
 
